package org.jeecg.modules.msgDistributor.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.msgDistributor.entity.MsgDistributor;
import org.jeecg.modules.msgDistributor.service.IMsgDistributorService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 分销商入驻
 * @Author: jeecg-boot
 * @Date:   2024-11-18
 * @Version: V1.0
 */
@Api(tags="分销商入驻")
@RestController
@RequestMapping("/msgDistributor/msgDistributor")
@Slf4j
public class MsgDistributorController extends JeecgController<MsgDistributor, IMsgDistributorService> {
	@Autowired
	private IMsgDistributorService msgDistributorService;
	
	/**
	 * 分页列表查询
	 *
	 * @param msgDistributor
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "分销商入驻-分页列表查询")
	@ApiOperation(value="分销商入驻-分页列表查询", notes="分销商入驻-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<MsgDistributor>> queryPageList(MsgDistributor msgDistributor,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<MsgDistributor> queryWrapper = QueryGenerator.initQueryWrapper(msgDistributor, req.getParameterMap());
		Page<MsgDistributor> page = new Page<MsgDistributor>(pageNo, pageSize);
		IPage<MsgDistributor> pageList = msgDistributorService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param msgDistributor
	 * @return
	 */
	@AutoLog(value = "分销商入驻-添加")
	@ApiOperation(value="分销商入驻-添加", notes="分销商入驻-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody MsgDistributor msgDistributor) {
		msgDistributorService.save(msgDistributor);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param msgDistributor
	 * @return
	 */
	@AutoLog(value = "分销商入驻-编辑")
	@ApiOperation(value="分销商入驻-编辑", notes="分销商入驻-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody MsgDistributor msgDistributor) {
		msgDistributorService.updateById(msgDistributor);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "分销商入驻-通过id删除")
	@ApiOperation(value="分销商入驻-通过id删除", notes="分销商入驻-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		msgDistributorService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "分销商入驻-批量删除")
	@ApiOperation(value="分销商入驻-批量删除", notes="分销商入驻-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.msgDistributorService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "分销商入驻-通过id查询")
	@ApiOperation(value="分销商入驻-通过id查询", notes="分销商入驻-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<MsgDistributor> queryById(@RequestParam(name="id",required=true) String id) {
		MsgDistributor msgDistributor = msgDistributorService.getById(id);
		if(msgDistributor==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(msgDistributor);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param msgDistributor
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, MsgDistributor msgDistributor) {
        return super.exportXls(request, msgDistributor, MsgDistributor.class, "分销商入驻");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, MsgDistributor.class);
    }

}
